==> jooq-3.6.2-sources.jar: org/jooq/impl/ProviderEnabledStatement.java <==
/**
 * Copyright (c) 2009-2015, Data Geekery GmbH (http://www.datageekery.com)
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Other licenses:
 * -----------------------------------------------------------------------------
 * Commercial licenses for this work are available. These replace the above
 * ASL 2.0 and offer limited warranties, support, maintenance, and commercial
 * database integrations.
 *
 * For more information, please visit: http://www.jooq.org/licenses
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */
package org.jooq.impl;

import java.sql.SQLException;
import java.sql.Statement;

import org.jooq.ConnectionProvider;
import org.jooq.tools.jdbc.DefaultStatement;

/**
 * A {@link ConnectionProvider}-enabled statement.
 *
 * @author Lukas Eder
 */
class ProviderEnabledStatement extends DefaultStatement {

    private final ProviderEnabledConnection connection;

    ProviderEnabledStatement(ProviderEnabledConnection connection, Statement statement) {
        super(statement);

        this.connection = connection;
    }

    // ------------------------------------------------------------------------
    // XXX Closing the Statement
    // ------------------------------------------------------------------------

    @Override
    public final void close() throws SQLException {
        try {
            getDelegate().close();
        }
        finally {
            connection.close();
        }
    }
}

==> jooq-3.11.9-sources.jar: org/jooq/impl/ProviderEnabledStatement.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Other licenses:
 * -----------------------------------------------------------------------------
 * Commercial licenses for this work are available. These replace the above
 * ASL 2.0 and offer limited warranties, support, maintenance, and commercial
 * database integrations.
 *
 * For more information, please visit: http://www.jooq.org/licenses
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */
package org.jooq.impl;

import java.sql.SQLException;
import java.sql.Statement;

import org.jooq.ConnectionProvider;
import org.jooq.tools.jdbc.DefaultStatement;

/**
 * A {@link ConnectionProvider}-enabled statement.
 *
 * @author Lukas Eder
 */
final class ProviderEnabledStatement extends DefaultStatement {

    private final ProviderEnabledConnection connection;

    ProviderEnabledStatement(ProviderEnabledConnection connection, Statement statement) {
        super(statement);

        this.connection = connection;
    }

    // ------------------------------------------------------------------------
    // XXX Closing the Statement
    // ------------------------------------------------------------------------

    @Override
    public final void close() throws SQLException {
        try {
            getDelegate().close();
        }
        finally {
            connection.close();
        }
    }
}
